@@ -17,7 +17,7 @@ use core::num::{NonZeroU32, Wrapping};
 use std::path::Path;
 
 use serde::{Deserialize, Serialize};
-use ssh_mux_format::{from_bytes, Serializer};
+use ssh_format::{from_bytes, Serializer};
 
 use std::os::unix::io::RawFd;
 
@@ -517,10 +517,7 @@ mod tests {
         let path = "/tmp/openssh-local-forward.socket";
 
         eprintln!("Creating remote process");
-        let cmd = format!(
-            "socat -dddd -u OPEN:/data UNIX-LISTEN:{} >/dev/stderr",
-            path
-        );
+        let cmd = format!("socat -u OPEN:/data UNIX-LISTEN:{} >/dev/stderr", path);
         let (established_session, stdios) = create_remote_process(conn0, &cmd).await;
 
         sleep(Duration::from_secs(1)).await;
